/**
 * @param {string} src
 * @param {number} start
 * @param {number} end
 * @returns {null | { pos: number, value: string }}
 */
export function parseMediaType(src: string, start: number, end: number): null | {
    pos: number;
    value: string;
};
/**
 * @typedef {{ src: string, type: string | null }} Source
 * @param {string} src
 * @param {number} start
 * @param {number} end
 * @param {markdownIt} [md]
 * @returns {null | { pos: number, res: Source }}
 */
export function parseMediaSource(src: string, start: number, end: number, md?: markdownIt | undefined): null | {
    pos: number;
    res: Source;
};
/**
 * @param {string} src
 * @param {number} start
 * @param {number} end
 * @returns {null | { pos: number, value: string }}
 */
export function parseNumber(src: string, start: number, end: number): null | {
    pos: number;
    value: string;
};
/**
 * @typedef {{ width: string, height: string }} SizeRes
 * @param {string} src
 * @param {number} start
 * @param {number} end
 * @returns {null | { pos: number, res: SizeRes }}
 */
export function parseMediaSize(src: string, start: number, end: number): null | {
    pos: number;
    res: SizeRes;
};
/**
 * @param {string} src
 * @param {number} start
 * @param {number} end
 * @param {markdownIt} [md]
 * @returns {null | { pos: number, value: string }}
 */
export function parseMediaPoster(src: string, start: number, end: number, md?: markdownIt | undefined): null | {
    pos: number;
    value: string;
};
/**
 * @param {string} src
 * @param {number} start
 * @param {number} end
 * @returns {null | { pos: number, value: string }}
 */
export function parseLanguageTag(src: string, start: number, end: number): null | {
    pos: number;
    value: string;
};
/**
 * @typedef {object} Captions
 * @property {string} src
 * @property {string} srclang
 * @property {string | null} label
 *
 * @param {string} src
 * @param {number} start
 * @param {number} end
 * @param {markdownIt} [md]
 * @returns {null | { pos: number, res: Captions }}
 */
export function parseMediaCaptions(src: string, start: number, end: number, md?: markdownIt | undefined): null | {
    pos: number;
    res: Captions;
};
/**
 * @typedef {object} MediaResponse
 * @property {Source[]} sources
 * @property {string} label
 * @property {string | null} title
 * @property {string | null} width
 * @property {string | null} height
 * @property {string | null} poster
 * @property {Captions[]} captions
 *
 * @param {StateInline} state
 * @param {number} start
 * @returns {null | { pos: number, res: Omit<MediaResponse, "label"> }}
 */
export function parseMediaArgs(state: StateInline, start: number): null | {
    pos: number;
    res: Omit<MediaResponse, "label">;
};
/**
 * @param {StateInline} state
 * @returns {null | { pos: number, res: MediaResponse }}
 */
export function parseMedia(state: StateInline): null | {
    pos: number;
    res: MediaResponse;
};
export type Token = InstanceType<markdownIt["core"]["State"]>["Token"];
export type Source = {
    src: string;
    type: string | null;
};
export type SizeRes = {
    width: string;
    height: string;
};
export type Captions = {
    src: string;
    srclang: string;
    label: string | null;
};
export type MediaResponse = {
    sources: Source[];
    label: string;
    title: string | null;
    width: string | null;
    height: string | null;
    poster: string | null;
    captions: Captions[];
};
export type StateInline = import("markdown-it/lib/rules_inline/state_inline.mjs").default;
import markdownIt from "markdown-it";
//# sourceMappingURL=parse.d.ts.map